# unitorch.cli.models.mt5

## MT5Processor

!!! tip
    **`core/process/mt5`** is the section for configuration of MT5Processor.

::: unitorch.cli.models.mt5.MT5Processor

## MT5ForGeneration

!!! tip
    **`core/model/generation/mt5`** is the section for configuration of MT5ForGeneration.

::: unitorch.cli.models.mt5.MT5ForGeneration
